summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorNicolas Boichat <drinkcat@chromium.org>2018-08-28 10:00:48 +0800
committerchrome-bot <chrome-bot@chromium.org>2018-08-29 11:15:54 -0700
commit2e4cd7bef7ef671d49ea7bb3ae55e9df970d8e25 (patch)
tree9a29794fe22b523a7d85976e9497c040290a2d49
parent61a3b8d663f54c3553f61a8b157f89b6bb17ed48 (diff)
downloadchrome-ec-2e4cd7bef7ef671d49ea7bb3ae55e9df970d8e25.tar.gz
kukui: Change FORCE_RESET to ODL
Also, FORCE_RESET is open-drain, active-low. Also, set the default to high. BRANCH=none BUG=b:112616655 TEST=boot rev1 to coreboot Change-Id: I33bd4a97831313f7bc5c3f0044c5b44d88932060 Signed-off-by: Nicolas Boichat <drinkcat@chromium.org> Reviewed-on: https://chromium-review.googlesource.com/1192722 Reviewed-by: Yilun Lin <yllin@chromium.org>
-rw-r--r--board/kukui/gpio.inc2
-rw-r--r--power/mt8183.c6
2 files changed, 4 insertions, 4 deletions
diff --git a/board/kukui/gpio.inc b/board/kukui/gpio.inc
index c4bb6db90e..660f54dfd2 100644
--- a/board/kukui/gpio.inc
+++ b/board/kukui/gpio.inc
@@ -74,7 +74,7 @@ GPIO(PP3300_S3_EN, PIN(D, 2), GPIO_OUT_LOW)
GPIO(AP_SYS_RST_L, PIN(C, 11), GPIO_OUT_LOW)
GPIO(PMIC_WATCHDOG_L, PIN(C, 3), GPIO_OUT_LOW)
GPIO(PMIC_EN_ODL, PIN(C, 10), GPIO_ODR_HIGH)
-GPIO(PMIC_FORCE_RESET, PIN(A, 2), GPIO_OUT_LOW)
+GPIO(PMIC_FORCE_RESET_ODL, PIN(A, 2), GPIO_ODR_HIGH)
GPIO(MT6370_RST_L, PIN(F, 0), GPIO_OUT_LOW)
/*
diff --git a/power/mt8183.c b/power/mt8183.c
index 2a4cef45b1..221e315892 100644
--- a/power/mt8183.c
+++ b/power/mt8183.c
@@ -190,7 +190,7 @@ enum power_state power_handle_state(enum power_state state)
case POWER_G3S5:
forcing_shutdown = 0;
- gpio_set_level(GPIO_PMIC_FORCE_RESET, 0);
+ gpio_set_level(GPIO_PMIC_FORCE_RESET_ODL, 1);
/* Power up to next state */
return POWER_S5;
@@ -288,7 +288,7 @@ enum power_state power_handle_state(enum power_state state)
case POWER_S5G3:
/*
* If PMIC is still not off, assert PMIC_FORCE_RESET.
* This should not happen if PMIC is configured properly, and
* shuts down upon receiving WATCHDOG.
*/
@@ -297,7 +297,7 @@ enum power_state power_handle_state(enum power_state state)
CPRINTS("Cannot force PMIC off (rev0)");
#else
CPRINTS("Forcing PMIC off");
- gpio_set_level(GPIO_PMIC_FORCE_RESET, 1);
+ gpio_set_level(GPIO_PMIC_FORCE_RESET_ODL, 0);
msleep(50);
return POWER_S5G3;
#endif
@@ -288,7 +288,7 @@ enum power_state power_handle_state(enum power_state state)
case POWER_S5G3:
/*
- * If PMIC is still not off, assert PMIC_FORCE_RESET.
+ * If PMIC is still not off, assert PMIC_FORCE_RESET_ODL.
* This should not happen if PMIC is configured properly, and
* shuts down upon receiving WATCHDOG.